@@ -4,8 +4,8 @@ Its purpose is to provide shorthands,
 and so should not be used in production code.
 It may be loaded with wildcard, eg:
 
-- from pylib.all import *  # executes all submodules
-- from pylib.math import * # won't execute the other submodules
+- from patlib.all import *  # executes all submodules
+- from patlib.math import * # won't execute the other submodules
 """
 
 from importlib.metadata import version
